@@ -2,10 +2,10 @@
 
 #
 # Creates distribution files
-# $Id: make-distrib.sh,v 1.28 2005/10/02 23:04:20 vaclavslavik Exp $
+# $Id: make-distrib.sh 1036 2006-09-10 15:18:36Z vaclavslavik $
 #
 
-VERSION=1.3.4
+VERSION=1.3.5
 
 #(
 #cd docs_classes
@@ -21,14 +21,13 @@ for i in *.po ; do msgfmt -o `basename $i .po`.mo $i ; done
 
 find_unix_files()
 {
-  (find . -type f -maxdepth 1 ; \
-  find admin locales src docs extras install -type f) | \
+  (find . -maxdepth 1 -type f ; \
+  find admin locales src docs extras install macosx -type f) | \
     grep -v '/win32-' | \
-    grep -v '/CVS' | \
+    grep -v '/\.svn' | \
     grep -v '\.#' | \
     grep -v '\.\(dsp\|dsw\|chm\|rtf\|iss\|ico\|ncb\|opt\|plg\|rc\)' | \
     grep -v 'install/.*\.txt'
-  echo 'docs_classes/Doxyfile'
 }
 
 find_win32_files()
