@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.h,v 1.44 2005/06/19 16:43:20 vaclavslavik Exp $
+ *  $Id: catalog.h 1008 2006-05-28 19:24:57Z vaclavslavik $
  *
  *  Translations catalog
  *
@@ -295,8 +295,10 @@ class CatalogParser
 
         /** Parses the entire file, calls OnEntry each time
             new msgid/msgstr pair is found.
+
+            @return false if parsing failed, true otherwise
          */
-        void Parse();
+        bool Parse();
 
     protected:
         /** Called when new entry was parsed. Parsing continues
