@@ -1,7 +1,7 @@
 /*
  *  This file is part of poEdit (http://www.poedit.org)
  *
- *  Copyright (C) 2003-2005 Vaclav Slavik
+ *  Copyright (C) 2003-2006 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: chooselang.cpp,v 1.34 2005/10/02 21:22:57 vaclavslavik Exp $
+ *  $Id: chooselang.cpp 1039 2006-09-15 06:52:39Z vaclavslavik $
  *
  *  Language chooser
  *
@@ -47,7 +47,7 @@ static void SaveUILanguage(wxLanguage lang)
 
 wxLanguage GetUILanguage()
 {
-#if defined(__UNIX__) || !wxCHECK_VERSION(2,5,0)
+#if !NEED_CHOOSELANG_UI
     return wxLANGUAGE_DEFAULT;
 #else
     wxLanguage lang(wxLANGUAGE_DEFAULT);
@@ -72,7 +72,7 @@ wxLanguage GetUILanguage()
 #endif
 }
 
-#ifndef __UNIX__
+#if NEED_CHOOSELANG_UI
 wxLanguage ChooseLanguage()
 {
     struct LangInfo
@@ -81,13 +81,14 @@ wxLanguage ChooseLanguage()
         wxLanguage code;
     };
 
-    LangInfo langs[] = 
+    LangInfo langs[] =
     {
         { _("(Use default language)"), wxLANGUAGE_DEFAULT },
 
         { _T("Afrikaans"), wxLANGUAGE_AFRIKAANS },
         { _T("Albanian"), wxLANGUAGE_ALBANIAN },
         { _T("Amharic"), wxLANGUAGE_AMHARIC },
+        { _T("Arabic"), wxLANGUAGE_ARABIC },
         { _T("Bangla"), wxLANGUAGE_BENGALI },
         { _T("Basque"), wxLANGUAGE_BASQUE },
         { _T("Belarusian"), wxLANGUAGE_BELARUSIAN },
@@ -122,6 +123,8 @@ wxLanguage ChooseLanguage()
         { _T("Kyrgyz"), wxLANGUAGE_KIRGHIZ },
         { _T("Latvian"), wxLANGUAGE_LATVIAN },
         { _T("Lithuanian"), wxLANGUAGE_LITHUANIAN },
+        { _T("Macedonian"), wxLANGUAGE_MACEDONIAN },
+        { _T("Malay"), wxLANGUAGE_MALAY },
         { _T("Mongolian"), wxLANGUAGE_MONGOLIAN },
         { _T("Norwegian Nynorsk"), wxLANGUAGE_NORWEGIAN_NYNORSK },
         { _T("Norwegian Bokmal"), wxLANGUAGE_NORWEGIAN_BOKMAL },
@@ -139,6 +142,7 @@ wxLanguage ChooseLanguage()
         { _T("Swedish"), wxLANGUAGE_SWEDISH },
         { _T("Tamil"), wxLANGUAGE_TAMIL },
         { _T("Tatarish"), wxLANGUAGE_TATAR },
+        { _T("Thai"), wxLANGUAGE_THAI },
         { _T("Turkish"), wxLANGUAGE_TURKISH },
         { _T("Ukrainian"), wxLANGUAGE_UKRAINIAN },
 
@@ -170,4 +174,4 @@ void ChangeUILanguage()
                  wxOK | wxCENTRE | wxICON_INFORMATION);
 }
 
-#endif
+#endif // NEED_CHOOSELANG_UI
