@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: chooselang.h,v 1.4 2005/06/19 16:43:20 vaclavslavik Exp $
+ *  $Id: chooselang.h 999 2006-03-12 18:44:26Z vaclavslavik $
  *
  *  Functions for choosing UI language
  *
@@ -33,7 +33,13 @@
 #include <wx/string.h>
 #include <wx/intl.h>
 
-#ifndef __UNIX__
+#if defined(__UNIX__) && !defined(__WXMAC__)
+    #define NEED_CHOOSELANG_UI 0
+#else
+    #define NEED_CHOOSELANG_UI 1
+#endif
+
+#if NEED_CHOOSELANG_UI
 /// Let the user select language
 wxLanguage ChooseLanguage();
 
@@ -43,6 +49,5 @@ void ChangeUILanguage();
 
 /** Return currently choosen language. Calls  ChooseLanguage if neccessary. */
 wxLanguage GetUILanguage();
-        
 
 #endif
