@@ -1,7 +1,7 @@
 /*
  *  This file is part of poEdit (http://www.poedit.org)
  *
- *  Copyright (C) 1999-2005 Vaclav Slavik
+ *  Copyright (C) 1999-2006 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edapp.cpp,v 1.52 2005/10/02 23:04:20 vaclavslavik Exp $
+ *  $Id: edapp.cpp 1032 2006-09-03 19:38:24Z vaclavslavik $
  *
  *  Application class
  *
@@ -37,6 +37,7 @@
 #include <wx/log.h>
 #include <wx/xrc/xmlres.h>
 #include <wx/xrc/xh_all.h>
+#include <wx/stdpaths.h>
 
 #include "edapp.h"
 #include "edframe.h"
@@ -73,25 +74,21 @@ wxString poEditApp::GetAppPath() const
 
 wxString poEditApp::GetAppVersion() const
 {
-    wxString version(_T("1.3.4"));
+    wxString version(_T("1.3.5"));
     return version;
 }
 
 
 static wxArrayString gs_filesToOpen;
 
-#ifdef __UNIX__
-#define CFG_FILE (home + _T(".poedit/config"))
-#else
-#define CFG_FILE wxEmptyString
-#endif
+extern void InitXmlResource();
 
 bool poEditApp::OnInit()
 {
     if (!wxApp::OnInit())
         return false;
 
-#ifdef __UNIX__
+#if defined(__UNIX__) && !defined(__WXMAC__)
     wxString home = wxGetHomeDir() + _T("/");
 
     // create poEdit cfg dir, move ~/.poedit to ~/.poedit/config
@@ -108,12 +105,26 @@ bool poEditApp::OnInit()
 
     SetVendorName(_T("Vaclav Slavik"));
     SetAppName(_T("poedit"));
+
+    #if defined(__WXMAC__)
+    #define CFG_FILE (wxStandardPaths::Get().GetUserConfigDir() + _T("/poedit.cfg"))
+    #elif defined(__UNIX__)
+    #define CFG_FILE (home + _T(".poedit/config"))
+    #else
+    #define CFG_FILE wxEmptyString
+    #endif
+
     wxConfigBase::Set(
         new wxConfig(wxEmptyString, wxEmptyString, CFG_FILE, wxEmptyString, 
                      wxCONFIG_USE_GLOBAL_FILE | wxCONFIG_USE_LOCAL_FILE));
     wxConfigBase::Get()->SetExpandEnvVars(false);
 
+#ifdef __WXMAC__
+    wxLocale::AddCatalogLookupPathPrefix(
+        wxStandardPaths::Get().GetResourcesDir() + _T("/locale"));
+#else
     wxLocale::AddCatalogLookupPathPrefix(GetAppPath() + _T("/share/locale"));
+#endif
 
     m_locale.Init(GetUILanguage());
     
@@ -121,37 +132,16 @@ bool poEditApp::OnInit()
     m_locale.AddCatalog(_T("poedit-wxstd")); // for semistatic builds
 
     wxImage::AddHandler(new wxGIFHandler);
-    wxFileSystem::AddHandler(new wxZipFSHandler);
-    
-    wxString resPath = GetAppPath() + _T("/share/poedit/resources.zip");
-    if (!wxFileExists(resPath))
-    {
-        wxString msg;
-        
-#ifdef __UNIX__
-        msg.Printf(_("Cannot find resources file '%s'!\n"
-                     "poEdit was configured to be installed in '%s'.\n"
-                     "You may try to set POEDIT_PREFIX environment variable to point\n"
-                     "to the location where you installed poEdit."), 
-                     resPath.c_str(), GetAppPath().c_str());
-#else
-        msg.Printf(_("Cannot find resources file '%s'!\nPlease reinstall poEdit."), 
-                     resPath.c_str());
-#endif
-        wxMessageBox(msg, _("poEdit Error"), wxOK | wxICON_ERROR);
-        return false;
-    }
-    else
-    {
-        wxXmlResource::Get()->InitAllHandlers();
-        wxXmlResource::Get()->Load(resPath);
-    }
-    
+    wxImage::AddHandler(new wxPNGHandler);
+    wxXmlResource::Get()->InitAllHandlers();
+    InitXmlResource();
+
     SetDefaultCfg(wxConfig::Get());
 
-    wxArtProvider::PushProvider(new wxPoeditStdArtProvider);
-#ifdef HAS_THEMES_SUPPORT
-    wxArtProvider::PushProvider(new wxPoeditThemeArtProvider);
+#ifdef HAS_INSERT_PROVIDER
+    wxArtProvider::InsertProvider(new PoeditArtProvider);
+#else
+    wxArtProvider::PushProvider(new PoeditArtProvider);
 #endif
 
     if (wxConfig::Get()->Read(_T("translator_name"), _T("nothing")) == _T("nothing"))
@@ -274,7 +264,9 @@ void poEditApp::SetDefaultCfg(wxConfigBase *cfg)
     if (cfg->Read(_T("TM/database_path"), wxEmptyString).IsEmpty())
     {
         wxString dbpath;
-#if defined(__UNIX__)
+#if defined(__WXMAC__)
+        dbpath = wxStandardPaths::Get().GetUserDataDir() + _T("/tm");
+#elif defined(__UNIX__)
         dbpath = wxGetHomeDir() + _T("/.poedit/tm");
 #elif defined(__WXMSW__)
         // VS: this distinguishes between NT and Win9X systems -- the former
