@@ -1,7 +1,7 @@
 /*
  *  This file is part of poEdit (http://www.poedit.org)
  *
- *  Copyright (C) 1999-2005 Vaclav Slavik
+ *  Copyright (C) 1999-2006 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: edframe.cpp,v 1.129 2005/09/30 22:30:28 vaclavslavik Exp $
+ *  $Id: edframe.cpp 1035 2006-09-04 08:52:18Z vaclavslavik $
  *
  *  Editor frame
  *
@@ -73,6 +73,26 @@ WX_DEFINE_LIST(poEditFramesList);
 poEditFramesList poEditFrame::ms_instances;
 
 
+// this should be high enough to not conflict with any wxNewId-allocated value,
+// but there's a check for this in the poEditFrame ctor, too
+const wxWindowID ID_POEDIT_FIRST = wxID_HIGHEST + 10000;
+const unsigned   ID_POEDIT_STEP  = 1000;
+
+const wxWindowID ID_POPUP_REFS   = ID_POEDIT_FIRST + 1*ID_POEDIT_STEP;
+const wxWindowID ID_POPUP_TRANS  = ID_POEDIT_FIRST + 2*ID_POEDIT_STEP;
+const wxWindowID ID_POPUP_DUMMY  = ID_POEDIT_FIRST + 3*ID_POEDIT_STEP;
+const wxWindowID ID_BOOKMARK_GO  = ID_POEDIT_FIRST + 4*ID_POEDIT_STEP;
+const wxWindowID ID_BOOKMARK_SET = ID_POEDIT_FIRST + 5*ID_POEDIT_STEP;
+
+const wxWindowID ID_POEDIT_LAST  = ID_POEDIT_FIRST + 6*ID_POEDIT_STEP;
+
+const wxWindowID ID_LIST = wxNewId();
+const wxWindowID ID_TEXTORIG = wxNewId();
+const wxWindowID ID_TEXTORIGPLURAL = wxNewId();
+const wxWindowID ID_TEXTTRANS = wxNewId();
+const wxWindowID ID_TEXTCOMMENT = wxNewId();
+
+
 
 #ifdef __VISUALC__
 // Disabling the useless and annoying MSVC++'s
@@ -114,23 +134,6 @@ poEditFramesList poEditFrame::ms_instances;
 }
 
 
-// Event & controls IDs:
-enum
-{
-    EDC_LIST        = 1000,
-    EDC_TEXTORIG,
-    EDC_TEXTORIGPLURAL,
-    EDC_TEXTTRANS,
-    EDC_TEXTCOMMENT,
-
-    ED_POPUP_REFS   = 2000,
-    ED_POPUP_TRANS  = 3000,
-    ED_POPUP_DUMMY  = 4000,
-
-    ED_BOOKMARK_GO  = 5000,
-    ED_BOOKMARK_SET = 5020
-};
-
 class ListHandler;
 class TextctrlHandler : public wxEvtHandler
 {
@@ -143,11 +146,7 @@ class TextctrlHandler : public wxEvtHandler
     private:
         void OnKeyDown(wxKeyEvent& event)
         {
-#if wxCHECK_VERSION(2,5,1)
             int keyCode = event.GetKeyCode();
-#else
-            int keyCode = event.KeyCode();
-#endif
 
             switch (keyCode)
             {
@@ -236,9 +235,9 @@ class ListHandler : public wxEvtHandler
 };
 
 BEGIN_EVENT_TABLE(ListHandler, wxEvtHandler)
-   EVT_LIST_ITEM_SELECTED  (EDC_LIST, ListHandler::OnSel)
-   EVT_LIST_ITEM_DESELECTED(EDC_LIST, ListHandler::OnDesel)
-   EVT_LIST_ITEM_ACTIVATED (EDC_LIST, ListHandler::OnActivated)
+   EVT_LIST_ITEM_SELECTED  (ID_LIST, ListHandler::OnSel)
+   EVT_LIST_ITEM_DESELECTED(ID_LIST, ListHandler::OnDesel)
+   EVT_LIST_ITEM_ACTIVATED (ID_LIST, ListHandler::OnActivated)
    EVT_RIGHT_DOWN          (          ListHandler::OnRightClick)
    EVT_SET_FOCUS           (          ListHandler::OnFocus)
    EVT_KEY_DOWN            (          ListHandler::OnKeyDown)
@@ -287,10 +286,10 @@ class UnfocusableTextCtrl : public wxTextCtrl
 
 
 BEGIN_EVENT_TABLE(poEditFrame, wxFrame)
-   EVT_MENU           (XRCID("menu_quit"),        poEditFrame::OnQuit)
+   EVT_MENU           (wxID_EXIT,                 poEditFrame::OnQuit)
    EVT_MENU           (XRCID("menu_help"),        poEditFrame::OnHelp)
    EVT_MENU           (XRCID("menu_help_gettext"),poEditFrame::OnHelpGettext)
-   EVT_MENU           (XRCID("menu_about"),       poEditFrame::OnAbout)
+   EVT_MENU           (wxID_ABOUT,                poEditFrame::OnAbout)
    EVT_MENU           (XRCID("menu_new"),         poEditFrame::OnNew)
    EVT_MENU           (XRCID("menu_new_from_pot"),poEditFrame::OnNew)
    EVT_MENU           (XRCID("menu_open"),        poEditFrame::OnOpen)
@@ -299,7 +298,7 @@ BEGIN_EVENT_TABLE(poEditFrame, wxFrame)
    EVT_MENU           (XRCID("menu_export"),      poEditFrame::OnExport)
    EVT_MENU_RANGE     (wxID_FILE1, wxID_FILE9,    poEditFrame::OnOpenHist)
    EVT_MENU           (XRCID("menu_catsettings"), poEditFrame::OnSettings)
-   EVT_MENU           (XRCID("menu_preferences"), poEditFrame::OnPreferences)
+   EVT_MENU           (wxID_PREFERENCES,          poEditFrame::OnPreferences)
    EVT_MENU           (XRCID("menu_update"),      poEditFrame::OnUpdate)
    EVT_MENU           (XRCID("menu_update_from_pot"),poEditFrame::OnUpdate)
    EVT_MENU           (XRCID("menu_purge_deleted"), poEditFrame::OnPurgeDeleted)
@@ -315,18 +314,18 @@ BEGIN_EVENT_TABLE(poEditFrame, wxFrame)
    EVT_MENU           (XRCID("menu_find"),        poEditFrame::OnFind)
    EVT_MENU           (XRCID("menu_comment"),     poEditFrame::OnEditComment)
    EVT_MENU           (XRCID("menu_manager"),     poEditFrame::OnManager)
-   EVT_MENU_RANGE     (ED_POPUP_REFS, ED_POPUP_REFS + 999, poEditFrame::OnReference)
+   EVT_MENU_RANGE     (ID_POPUP_REFS, ID_POPUP_REFS + 999, poEditFrame::OnReference)
 #ifdef USE_TRANSMEM
-   EVT_MENU_RANGE     (ED_POPUP_TRANS, ED_POPUP_TRANS + 999,
+   EVT_MENU_RANGE     (ID_POPUP_TRANS, ID_POPUP_TRANS + 999,
                        poEditFrame::OnAutoTranslate)
    EVT_MENU           (XRCID("menu_auto_translate"), poEditFrame::OnAutoTranslateAll)
 #endif
-   EVT_MENU_RANGE     (ED_BOOKMARK_GO, ED_BOOKMARK_GO + 9,
+   EVT_MENU_RANGE     (ID_BOOKMARK_GO, ID_BOOKMARK_GO + 9,
                        poEditFrame::OnGoToBookmark)
-   EVT_MENU_RANGE     (ED_BOOKMARK_SET, ED_BOOKMARK_SET + 9,
+   EVT_MENU_RANGE     (ID_BOOKMARK_SET, ID_BOOKMARK_SET + 9,
                        poEditFrame::OnSetBookmark)
    EVT_CLOSE          (                poEditFrame::OnCloseWindow)
-   EVT_TEXT           (EDC_TEXTCOMMENT,poEditFrame::OnCommentWindowText)
+   EVT_TEXT           (ID_TEXTCOMMENT,poEditFrame::OnCommentWindowText)
 #ifdef __WXMSW__
    EVT_DROP_FILES     (poEditFrame::OnFileDrop)
 #endif
@@ -343,7 +342,9 @@ poEditFrame::poEditFrame() :
                                  wxConfig::Get()->Read(_T("frame_w"), 600),
                                  wxConfig::Get()->Read(_T("frame_h"), 400)),
                              wxDEFAULT_FRAME_STYLE | wxNO_FULL_REPAINT_ON_RESIZE),
+#if USE_GETTEXT_VALIDATION
     m_itemBeingValidated(-1), m_gettextProcess(NULL),
+#endif
     m_catalog(NULL),
 #ifdef USE_TRANSMEM
     m_transMem(NULL),
@@ -355,6 +356,12 @@ poEditFrame::poEditFrame() :
     m_sel(-1), //m_selItem(0),
     m_edittedTextFuzzyChanged(false)
 {
+    // make sure that the [ID_POEDIT_FIRST,ID_POEDIT_LAST] range of IDs is not
+    // used for anything else:
+    wxASSERT_MSG( wxGetCurrentId() < ID_POEDIT_FIRST,
+                  _("detected ID values conflict!") );
+    wxRegisterId(ID_POEDIT_LAST);
+
 #ifdef __WXMSW__
     const int SPLITTER_BORDER = wxSP_NOBORDER;
 #else
@@ -387,13 +394,13 @@ poEditFrame::poEditFrame() :
     gs_shadedList = (bool)cfg->Read(_T("shaded_list"), (long)true);
 
 #ifdef __UNIX__
-    SetIcon(wxArtProvider::GetIcon(_T("poedit-appicon")));
+    SetIcon(wxArtProvider::GetIcon(_T("poedit")));
 #else
     SetIcon(wxICON(appicon));
 #endif
 
 #ifdef CAN_MODIFY_DEFAULT_FONT
-    m_boldGuiFont = wxSystemSettings::GetSystemFont(wxSYS_DEFAULT_GUI_FONT);
+    m_boldGuiFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
     m_boldGuiFont.SetWeight(wxFONTWEIGHT_BOLD);
 #endif
 
@@ -431,7 +438,7 @@ poEditFrame::poEditFrame() :
                                       SPLITTER_BORDER);
 
     m_list = new poEditListCtrl(m_splitter,
-                                EDC_LIST,
+                                ID_LIST,
                                 wxDefaultPosition, wxDefaultSize,
                                 wxLC_REPORT | wxLC_SINGLE_SEL,
                                 m_displayLines);
@@ -444,7 +451,7 @@ poEditFrame::poEditFrame() :
 
     m_textComment = NULL;
     m_textAutoComments = new UnfocusableTextCtrl(m_bottomRightPanel,
-                                EDC_TEXTORIG, wxEmptyString,
+                                ID_TEXTORIG, wxEmptyString,
                                 wxDefaultPosition, wxDefaultSize,
                                 wxTE_MULTILINE | wxTE_READONLY);
     // This call will force the creation of the right kind of control
@@ -454,16 +461,16 @@ poEditFrame::poEditFrame() :
     m_labelSingular = new wxStaticText(m_bottomLeftPanel, -1, _("Singular:"));
     m_labelPlural = new wxStaticText(m_bottomLeftPanel, -1, _("Plural:"));
     m_textOrig = new UnfocusableTextCtrl(m_bottomLeftPanel,
-                                EDC_TEXTORIG, wxEmptyString,
+                                ID_TEXTORIG, wxEmptyString,
                                 wxDefaultPosition, wxDefaultSize,
                                 wxTE_MULTILINE | wxTE_READONLY);
     m_textOrigPlural = new UnfocusableTextCtrl(m_bottomLeftPanel,
-                                EDC_TEXTORIGPLURAL, wxEmptyString,
+                                ID_TEXTORIGPLURAL, wxEmptyString,
                                 wxDefaultPosition, wxDefaultSize,
                                 wxTE_MULTILINE | wxTE_READONLY);
 
     m_textTrans = new wxTextCtrl(m_bottomLeftPanel,
-                                EDC_TEXTTRANS, wxEmptyString,
+                                ID_TEXTTRANS, wxEmptyString,
                                 wxDefaultPosition, wxDefaultSize,
                                 wxTE_MULTILINE);
 
@@ -500,20 +507,8 @@ poEditFrame::poEditFrame() :
     m_bottomRightPanel->SetSizer(rightSizer);
 
     m_bottomSplitter->SetMinimumPaneSize(40);
-    if (m_displayCommentWin || m_displayAutoCommentsWin)
-    {
-        m_bottomSplitter->SplitVertically(m_bottomLeftPanel, m_bottomRightPanel,
-                                          cfg->Read(_T("bottom_splitter"),
-                                                    -200L));
-        m_bottomLeftPanel->GetSizer()->Show(m_textComment, m_displayCommentWin);
-        m_bottomLeftPanel->GetSizer()->Show(m_textAutoComments, m_displayAutoCommentsWin);
-        m_bottomLeftPanel->GetSizer()->Layout();
-    }
-    else
-    {
-        m_bottomRightPanel->Show(false);
-        m_bottomSplitter->Initialize(m_bottomLeftPanel);
-    }
+    m_bottomRightPanel->Show(false);
+    m_bottomSplitter->Initialize(m_bottomLeftPanel);
 
     m_splitter->SetMinimumPaneSize(40);
     m_splitter->SplitHorizontally(m_list, m_bottomSplitter, cfg->Read(_T("splitter"), 240L));
@@ -537,23 +532,10 @@ poEditFrame::poEditFrame() :
     ShowPluralFormUI(false);
 
     UpdateMenu();
+    UpdateDisplayCommentWin();
 
-    wxString cannon = wxGetApp().GetLocale().GetCanonicalName().Left(2);
-    wxString datadir = wxGetApp().GetAppPath() + _T("/share/poedit");
-    wxString book;
-#if defined(__WXMSW__)
-    book.Printf(_T("%s/poedit-%s.chm"), datadir.c_str(), cannon.c_str());
-    if (!wxFileExists(book))
-        book.Printf(_T("%s/poedit.chm"), datadir.c_str());
-    m_help.Initialize(book);
-    m_helpBook = book;
-#elif defined(__UNIX__)
-    book.Printf(_T("%s/help-%s.zip"), datadir.c_str(), cannon.c_str());
-    if (!wxFileExists(book))
-        book.Printf(_T("%s/help.zip"), datadir.c_str());
-    m_help.Initialize(book);
-    m_help.AddBook(datadir + _T("/help-gettext.zip"));
-#endif
+    m_helpBook = LoadHelpBook(_T("poedit"));
+    m_helpBookGettext = LoadHelpBook(_T("gettext/gettext"));
 
     ms_instances.Append(this);
 
@@ -566,8 +548,10 @@ poEditFrame::poEditFrame() :
 
 poEditFrame::~poEditFrame()
 {
+#if USE_GETTEXT_VALIDATION
     if (m_gettextProcess)
         m_gettextProcess->Detach();
+#endif
 
     ms_instances.DeleteObject(this);
 
@@ -577,7 +561,10 @@ poEditFrame::~poEditFrame()
 
     wxSize sz = GetSize();
     wxPoint pos = GetPosition();
+
     wxConfigBase *cfg = wxConfig::Get();
+    cfg->SetPath(_T("/"));
+
     if (!IsIconized() && !IsFullScreen())
     {
         if (!IsMaximized())
@@ -591,9 +578,11 @@ poEditFrame::~poEditFrame()
         cfg->Write(_T("frame_maximized"), (long)IsMaximized());
     }
 
-    if (m_displayCommentWin)
+    if (m_displayCommentWin || m_displayAutoCommentsWin)
+    {
         cfg->Write(_T("bottom_splitter"),
                    (long)m_bottomSplitter->GetSashPosition());
+    }
     cfg->Write(_T("splitter"), (long)m_splitter->GetSashPosition());
     cfg->Write(_T("display_quotes"), m_displayQuotes);
     cfg->Write(_T("display_lines"), m_displayLines);
@@ -603,18 +592,64 @@ poEditFrame::~poEditFrame()
 
     m_history.Save(*cfg);
 
+    // write all changes:
+    cfg->Flush();
+
 #ifdef USE_TRANSMEM
     if (m_transMem)
         m_transMem->Release();
 #endif
-    delete m_catalog;
 
+    delete m_catalog;
     m_catalog = NULL;
+    m_list->CatalogChanged(NULL);
 
     // shutdown the spellchecker:
     InitSpellchecker();
 }
 
+wxString poEditFrame::LoadHelpBook(const wxString& name)
+{
+    wxString lng = wxGetApp().GetLocale().GetCanonicalName().Left(2);
+    wxString helpdir = wxGetApp().GetAppPath() + _T("/share/poedit/help");
+
+#ifdef __WXMSW__
+    #define HLPEXT _T("chm")
+#else
+    #define HLPEXT _T("hhp")
+#endif
+
+    wxLogTrace(_T("poedit.help"),
+               _T("looking for help book '%s' under %s"),
+               name.c_str(), helpdir.c_str());
+
+    wxString file;
+    file.Printf(_T("%s/%s/%s.%s"),
+                helpdir.c_str(), lng.c_str(), name.c_str(), HLPEXT);
+    wxLogTrace(_T("poedit.help"), _T("trying %s"), file.c_str());
+
+    if (!wxFileExists(file))
+    {
+        file.Printf(_T("%s/en/%s.%s"),
+                    helpdir.c_str(), name.c_str(), HLPEXT);
+        wxLogTrace(_T("poedit.help"), _T("trying %s"), file.c_str());
+    }
+
+    if (!wxFileExists(file))
+    {
+        wxLogTrace(_T("poedit.help"), _T("not found"));
+        return wxEmptyString;
+    }
+
+    wxLogTrace(_T("poedit.help"), _T("using help file %s"), file.c_str());
+    m_help.Initialize(file);
+#ifndef __WXMSW__
+    m_help.AddBook(file);
+#endif
+
+    return file;
+}
+
 #if USE_SPELLCHECKING
 // helper functions that finds GtkTextView of wxTextCtrl:
 static GtkTextView *GetTextView(wxTextCtrl *ctrl)
@@ -1235,7 +1270,7 @@ void poEditFrame::OnReferencesMenu(wxCommandEvent& event)
 
 void poEditFrame::OnReference(wxCommandEvent& event)
 {
-    ShowReference(event.GetId() - ED_POPUP_REFS);
+    ShowReference(event.GetId() - ID_POPUP_REFS);
 }
 
 
@@ -1553,8 +1588,10 @@ void poEditFrame::UpdateFromTextCtrl(int item)
 
     UpdateStatusBar();
 
+#if USE_GETTEXT_VALIDATION
     // check validity of this item:
     m_itemsToValidate.push_front(item);
+#endif
 }
 
 
@@ -1652,8 +1689,13 @@ void poEditFrame::ReadCatalog(const wxString& catalog)
 {
     CancelItemsValidation();
 
+    Catalog *cat = new Catalog(catalog);
+    if (!cat->IsOk())
+        return;
+
     delete m_catalog;
-    m_catalog = new Catalog(catalog);
+    m_catalog = cat;
+
     m_list->CatalogChanged(m_catalog);
     dynamic_cast<TextctrlHandler*>(m_textTrans->GetEventHandler())->SetCatalog(m_catalog);
 
@@ -1771,6 +1813,7 @@ void poEditFrame::UpdateStatusBar()
         txt.Printf(_("%i strings (%i fuzzy, %i bad tokens, %i not translated)"),
                    all, fuzzy, badtokens, untranslated);
 
+#if USE_GETTEXT_VALIDATION
         if (!m_itemsToValidate.empty())
         {
             wxString progress;
@@ -1779,6 +1822,7 @@ void poEditFrame::UpdateStatusBar()
             txt += _T("    ");
             txt += progress;
         }
+#endif
 
         GetStatusBar()->SetStatusText(txt);
         if (all > 0)
@@ -1856,8 +1900,8 @@ void poEditFrame::UpdateMenu()
     menubar->EnableTop(4, m_catalog != NULL);
     for (int i = 0; i < 10; i++)
     {
-        menubar->Enable(ED_BOOKMARK_SET + i, m_catalog != NULL);
-        menubar->Enable(ED_BOOKMARK_GO + i,
+        menubar->Enable(ID_BOOKMARK_SET + i, m_catalog != NULL);
+        menubar->Enable(ID_BOOKMARK_GO + i,
                         m_catalog != NULL &&
                         m_catalog->GetBookmarkIndex(Bookmark(i)) != -1);
     }
@@ -1949,7 +1993,7 @@ void poEditFrame::OnPurgeDeleted(wxCommandEvent& WXUNUSED(event))
 #ifdef USE_TRANSMEM
 void poEditFrame::OnAutoTranslate(wxCommandEvent& event)
 {
-    int ind = event.GetId() - ED_POPUP_TRANS;
+    int ind = event.GetId() - ID_POPUP_TRANS;
     (*m_catalog)[m_list->GetIndexInCatalog(m_sel)].SetTranslation(m_autoTranslations[ind]);
     UpdateToTextCtrl();
     // VS: This dirty trick ensures proper refresh of everything:
@@ -2017,27 +2061,27 @@ wxMenu *poEditFrame::GetPopupMenu(size_t item)
     menu->AppendSeparator();
 
 #ifdef CAN_MODIFY_DEFAULT_FONT
-    wxMenuItem *it1 = new wxMenuItem(menu, ED_POPUP_DUMMY+0, _("References:"));
+    wxMenuItem *it1 = new wxMenuItem(menu, ID_POPUP_DUMMY+0, _("References:"));
     it1->SetFont(m_boldGuiFont);
     menu->Append(it1);
 #else
-    menu->Append(ED_POPUP_DUMMY+0, _("References:"));
+    menu->Append(ID_POPUP_DUMMY+0, _("References:"));
 #endif
     menu->AppendSeparator();
     for (size_t i = 0; i < refs.GetCount(); i++)
-        menu->Append(ED_POPUP_REFS + i, _T("   ") + refs[i]);
+        menu->Append(ID_POPUP_REFS + i, _T("   ") + refs[i]);
 
 #ifdef USE_TRANSMEM
     if (GetTransMem())
     {
         menu->AppendSeparator();
 #ifdef CAN_MODIFY_DEFAULT_FONT
-        wxMenuItem *it2 = new wxMenuItem(menu, ED_POPUP_DUMMY+1,
+        wxMenuItem *it2 = new wxMenuItem(menu, ID_POPUP_DUMMY+1,
                                          _("Automatic translations:"));
         it2->SetFont(m_boldGuiFont);
         menu->Append(it2);
 #else
-        menu->Append(ED_POPUP_DUMMY+1, _("Automatic translations:"));
+        menu->Append(ID_POPUP_DUMMY+1, _("Automatic translations:"));
 #endif
         menu->AppendSeparator();
 
@@ -2052,13 +2096,13 @@ wxMenu *poEditFrame::GetPopupMenu(size_t item)
                 wxString s(m_autoTranslations[i].wc_str(wxConvUTF8), wxConvLocal);
                 if (!s)
                     s = m_autoTranslations[i];
-                menu->Append(ED_POPUP_TRANS + i, _T("   ") + s);
+                menu->Append(ID_POPUP_TRANS + i, _T("   ") + s);
             }
         }
         else
         {
-            menu->Append(ED_POPUP_DUMMY+2, _("none"));
-            menu->Enable(ED_POPUP_DUMMY+2, false);
+            menu->Append(ID_POPUP_DUMMY+2, _("none"));
+            menu->Enable(ID_POPUP_DUMMY+2, false);
         }
     }
 #endif
@@ -2130,8 +2174,7 @@ void poEditFrame::SetCustomFonts()
     }
     else if (prevUseFontList)
     {
-        m_list->SetFont(
-                wxSystemSettings::GetSystemFont(wxSYS_DEFAULT_GUI_FONT));
+        m_list->SetFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
         prevUseFontList = false;
     }
 
@@ -2156,7 +2199,7 @@ void poEditFrame::SetCustomFonts()
     }
     else if (prevUseFontText)
     {
-        wxFont font(wxSystemSettings::GetSystemFont(wxSYS_DEFAULT_GUI_FONT));
+        wxFont font(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
         m_textComment->SetFont(font);
         m_textAutoComments->SetFont(font);
         m_textOrig->SetFont(font);
@@ -2182,14 +2225,14 @@ void poEditFrame::UpdateCommentWindowEditable()
         if (m_commentWindowEditable)
         {
             m_textComment = new wxTextCtrl(m_bottomRightPanel,
-                                        EDC_TEXTCOMMENT, wxEmptyString,
+                                        ID_TEXTCOMMENT, wxEmptyString,
                                         wxDefaultPosition, wxDefaultSize,
                                         wxTE_MULTILINE);
         }
         else
         {
             m_textComment = new UnfocusableTextCtrl(m_bottomRightPanel,
-                                        EDC_TEXTCOMMENT, wxEmptyString,
+                                        ID_TEXTCOMMENT, wxEmptyString,
                                         wxDefaultPosition, wxDefaultSize,
                                         wxTE_MULTILINE | wxTE_READONLY);
         }
@@ -2227,12 +2270,16 @@ void poEditFrame::UpdateDisplayCommentWin()
             m_bottomRightPanel->GetSizer()->Show(m_textAutoComments,
                                                  m_displayAutoCommentsWin);
             m_bottomRightPanel->GetSizer()->Layout();
+            m_bottomRightPanel->Layout();
         }
     }
     else
     {
-        wxConfig::Get()->Write(_T("bottom_splitter"),
-                               (long)m_bottomSplitter->GetSashPosition());
+        if ( m_bottomSplitter->IsSplit() )
+        {
+            wxConfig::Get()->Write(_T("bottom_splitter"),
+                                   (long)m_bottomSplitter->GetSashPosition());
+        }
         m_bottomRightPanel->Show(false);
         m_bottomSplitter->Unsplit();
     }
@@ -2269,36 +2316,45 @@ void poEditFrame::OnCommentWindowText(wxCommandEvent&)
 
 void poEditFrame::OnIdle(wxIdleEvent& event)
 {
+#if USE_GETTEXT_VALIDATION
     if (!m_itemsToValidate.empty() && m_itemBeingValidated == -1)
         BeginItemValidation();
+#endif
     event.Skip();
 }
 
 void poEditFrame::OnEndProcess(wxProcessEvent& event)
 {
+#if USE_GETTEXT_VALIDATION
     m_gettextProcess = NULL;
     event.Skip(); // deletes wxProcess object
     EndItemValidation();
     wxWakeUpIdle();
+#endif
 }
 
 void poEditFrame::CancelItemsValidation()
 {
+#if USE_GETTEXT_VALIDATION
     // stop checking entries in the background:
     m_itemsToValidate.clear();
     m_itemBeingValidated = -1;
+#endif
 }
 
 void poEditFrame::RestartItemsValidation()
 {
+#if USE_GETTEXT_VALIDATION
     // start checking catalog's entries in the background:
     int cnt = m_list->GetItemCount();
     for (int i = 0; i < cnt; i++)
         m_itemsToValidate.push_back(i);
+#endif
 }
 
 void poEditFrame::BeginItemValidation()
 {
+#if USE_GETTEXT_VALIDATION
     int item = m_itemsToValidate.front();
     int index = m_list->GetIndexInCatalog(item);
     CatalogData& dt = (*m_catalog)[index];
@@ -2342,10 +2398,12 @@ void poEditFrame::BeginItemValidation()
     {
         EndItemValidation();
     }
+#endif
 }
 
 void poEditFrame::EndItemValidation()
 {
+#if USE_GETTEXT_VALIDATION
     wxASSERT( m_catalog );
 
     wxRemoveFile(m_validationProcess.tmp1);
@@ -2396,6 +2454,7 @@ void poEditFrame::EndItemValidation()
                        _T("finished checking validity in background"));
         }
     }
+#endif
 }
 
 void poEditFrame::ShowPluralFormUI(bool show)
@@ -2404,27 +2463,9 @@ void poEditFrame::ShowPluralFormUI(bool show)
         show = false;
 
     wxSizer *origSizer = m_textOrig->GetContainingSizer();
-#if wxCHECK_VERSION(2,5,0)
     origSizer->Show(m_labelSingular, show);
     origSizer->Show(m_labelPlural, show);
     origSizer->Show(m_textOrigPlural, show);
-#else
-    // the above code doesn't work well with wx-2.4, so here's a no-so-good
-    // workaround:
-    if (show && m_labelSingular->GetSizer() == NULL)
-    {
-        origSizer->Add(m_labelPlural, 0, wxALIGN_CENTER_VERTICAL | wxALL, 3);
-        origSizer->Add(m_textOrigPlural, 1, wxEXPAND);
-        origSizer->SetItemMinSize(m_textOrigPlural, 1, 1);
-    }
-    else
-    {
-        origSizer->Remove(m_labelPlural);
-        origSizer->Remove(m_textOrigPlural);
-    }
-    m_labelPlural->Show(show);
-    m_textOrigPlural->Show(show);
-#endif
     origSizer->Layout();
 
     wxSizer *textSizer = m_textTrans->GetContainingSizer();
@@ -2533,13 +2574,13 @@ void poEditFrame::AddBookmarksMenu()
 
     for (int i = 0; i < 10; i++)
     {
-        menu->Append(ED_BOOKMARK_SET + i,
+        menu->Append(ID_BOOKMARK_SET + i,
                      wxString::Format(_("Set bookmark %i\tAlt-%i"), i, i));
     }
     menu->AppendSeparator();
     for (int i = 0; i < 10; i++)
     {
-        menu->Append(ED_BOOKMARK_GO + i,
+        menu->Append(ID_BOOKMARK_GO + i,
                      wxString::Format(_("Go to bookmark %i\tCtrl-%i"), i, i));
     }
 
@@ -2550,7 +2591,7 @@ void poEditFrame::AddBookmarksMenu()
 void poEditFrame::OnGoToBookmark(wxCommandEvent& event)
 {
     // Go to bookmark, if there is an item for it
-    Bookmark bk = static_cast<Bookmark>(event.GetId() - ED_BOOKMARK_GO);
+    Bookmark bk = static_cast<Bookmark>(event.GetId() - ID_BOOKMARK_GO);
     int bkIndex = m_catalog->GetBookmarkIndex(bk);
     if (bkIndex != -1)
     {
@@ -2571,7 +2612,7 @@ void poEditFrame::OnSetBookmark(wxCommandEvent& event)
     int bkIndex = -1;
     int selItemIndex = m_list->GetIndexInCatalog(m_sel);
 
-    Bookmark bk = static_cast<Bookmark>(event.GetId() - ED_BOOKMARK_SET);
+    Bookmark bk = static_cast<Bookmark>(event.GetId() - ID_BOOKMARK_SET);
     if (m_catalog->GetBookmarkIndex(bk) == selItemIndex)
     {
         m_catalog->SetBookmark(selItemIndex, NO_BOOKMARK);
