@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edframe.h,v 1.52 2005/09/30 22:19:04 vaclavslavik Exp $
+ *  $Id: edframe.h 1025 2006-09-01 19:29:40Z vaclavslavik $
  *
  *  Editor frame
  *
@@ -34,6 +34,10 @@
   #define CAN_MODIFY_DEFAULT_FONT
 #endif
 
+// disable on-the-fly gettext validation, launching so many xmsgfmt
+// processes doesn't work well:
+#define USE_GETTEXT_VALIDATION 0
+
 #include <list>
 
 #include <wx/frame.h>
@@ -216,9 +220,12 @@ class poEditFrame : public wxFrame
 
         void RecreatePluralTextCtrls();
 
+        wxString LoadHelpBook(const wxString& name);
+
         DECLARE_EVENT_TABLE()
 
     private:
+#if USE_GETTEXT_VALIDATION
         struct ValidationProcessData : public GettextProcessData
         {
             wxString tmp1, tmp2;
@@ -228,6 +235,7 @@ class poEditFrame : public wxFrame
         int m_itemBeingValidated;
         std::list<int> m_itemsToValidate;
         ValidationProcessData m_validationProcess;
+#endif
 
         bool m_commentWindowEditable;
         Catalog *m_catalog;
@@ -241,10 +249,10 @@ class poEditFrame : public wxFrame
 
 #ifdef __WXMSW__
         wxCHMHelpController m_help;
-        wxString m_helpBook;
 #else
         wxHtmlHelpController m_help;
 #endif
+        wxString m_helpBook, m_helpBookGettext;
 
         wxPanel *m_bottomLeftPanel;
         wxPanel *m_bottomRightPanel;
