@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: manager.cpp,v 1.24 2005/07/05 22:21:06 vaclavslavik Exp $
+ *  $Id: manager.cpp 1022 2006-08-31 21:57:29Z vaclavslavik $
  *
  *  Catalogs manager frame
  *
@@ -75,7 +75,7 @@ ManagerFrame::ManagerFrame() :
                              wxDEFAULT_FRAME_STYLE | wxNO_FULL_REPAINT_ON_RESIZE)
 {
 #ifdef __UNIX__
-    SetIcon(wxArtProvider::GetIcon(_T("poedit-appicon")));
+    SetIcon(wxArtProvider::GetIcon(_T("poedit")));
 #else
     SetIcon(wxICON(appicon));
 #endif
@@ -363,7 +363,7 @@ BEGIN_EVENT_TABLE(ManagerFrame, wxFrame)
    EVT_MENU                 (XRCID("prj_update"), ManagerFrame::OnUpdateProject)
    EVT_LISTBOX              (XRCID("prj_list"),   ManagerFrame::OnSelectProject)
    EVT_LIST_ITEM_ACTIVATED  (XRCID("prj_files"),  ManagerFrame::OnOpenCatalog)
-   EVT_MENU                 (XRCID("menu_quit"),  ManagerFrame::OnQuit)
+   EVT_MENU                 (wxID_EXIT,           ManagerFrame::OnQuit)
    EVT_MENU                 (XRCID("menu_preferences"), ManagerFrame::OnPreferences)
 END_EVENT_TABLE()
 
