@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: prefsdlg.cpp,v 1.34 2005/06/19 16:43:21 vaclavslavik Exp $
+ *  $Id: prefsdlg.cpp 999 2006-03-12 18:44:26Z vaclavslavik $
  *
  *  Preferences settings dialog
  *
@@ -84,10 +84,10 @@ PreferencesDialog::PreferencesDialog(wxWindow *parent)
     GetSizer()->Fit(this);
 #endif
 
-#ifdef __UNIX__
+#if !NEED_CHOOSELANG_UI
     // remove (defunct on Unix) "Change UI language" button:
     XRCCTRL(*this, "ui_language", wxButton)->Show(false);
-#endif    
+#endif
 }
 
 
@@ -246,12 +246,12 @@ BEGIN_EVENT_TABLE(PreferencesDialog, wxDialog)
    EVT_BUTTON(XRCID("tm_browsedbpath"), PreferencesDialog::OnTMBrowseDbPath)
    EVT_BUTTON(XRCID("tm_generate"), PreferencesDialog::OnTMGenerate)
 #endif
-#ifndef __UNIX__
+#if NEED_CHOOSELANG_UI
    EVT_BUTTON(XRCID("ui_language"), PreferencesDialog::OnUILanguage)
 #endif
 END_EVENT_TABLE()
-    
-#ifndef __UNIX__
+
+#if NEED_CHOOSELANG_UI
 void PreferencesDialog::OnUILanguage(wxCommandEvent& event)
 {
     ChangeUILanguage();
