@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: prefsdlg.h,v 1.10 2005/06/19 16:43:21 vaclavslavik Exp $
+ *  $Id: prefsdlg.h 999 2006-03-12 18:44:26Z vaclavslavik $
  *
  *  Preferences settings dialog
  *
@@ -33,6 +33,7 @@
 #include <wx/dialog.h>
 
 #include "parser.h"
+#include "chooselang.h"
 
 class WXDLLEXPORT wxConfigBase;
 
@@ -63,7 +64,7 @@ class PreferencesDialog : public wxDialog
         void OnTMGenerate(wxCommandEvent& event);
 #endif
 
-#ifndef __UNIX__
+#if NEED_CHOOSELANG_UI
         void OnUILanguage(wxCommandEvent& event);
 #endif
         void OnNewParser(wxCommandEvent& event);
