@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: transmem.cpp,v 1.21 2005/06/19 16:43:21 vaclavslavik Exp $
+ *  $Id: transmem.cpp 1031 2006-09-03 19:37:44Z vaclavslavik $
  *
  *  Translation memory database
  *
@@ -154,6 +154,7 @@
 #include <wx/log.h>
 #include <wx/intl.h>
 #include <wx/utils.h>
+#include <wx/filename.h>
 
 #include DB_HEADER
 
@@ -719,8 +720,7 @@ TranslationMemoriesList TranslationMemory::ms_instances;
     if (!dbPath)
         dbPath = path + _T("/") + language;
 
-    if ((!wxDirExists(path) && !wxMkdir(path)) ||
-        (!wxDirExists(dbPath) && !wxMkdir(dbPath)))
+    if ( !wxFileName::Mkdir(dbPath, 0777, wxPATH_MKDIR_FULL) )
     {
         wxLogError(_("Cannot create database directory!"));
         return NULL;
